sw/vec_iree: Rename springbok_* to sparrow_*

Renaming only. No other changes.

Change-Id: I47953c8653b77e607ecfcc26a8a1ecab3624c769
diff --git a/CMakeLists.txt b/CMakeLists.txt
index b89471a..023e4c6 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -19,7 +19,7 @@
 include_directories(BEFORE SYSTEM ${CMAKE_CURRENT_BINARY_DIR})
 
 #-------------------------------------------------------------------------------
-# Springbok-specific settings
+# Sparrow-specific settings
 #-------------------------------------------------------------------------------
 set(TCM_LENGTH "16M" CACHE STRING "TCM Length (default: 16M)")
 add_link_options("LINKER:--defsym=__tcm_length__=${TCM_LENGTH}")
@@ -50,11 +50,11 @@
 #-------------------------------------------------------------------------------
 # IREE-specific definitions
 #-------------------------------------------------------------------------------
-set(SPRINGBOK_CONFIG_HEADER "${CMAKE_CURRENT_SOURCE_DIR}/springbok_config.h")
+set(SPARROW_CONFIG_HEADER "${CMAKE_CURRENT_SOURCE_DIR}/sparrow_config.h")
 add_compile_definitions(FLATCC_USE_GENERIC_ALIGNED_ALLOC)
 add_compile_definitions(IREE_SYNCHRONIZATION_DISABLE_UNSAFE=1)
 add_compile_definitions(IREE_FILE_IO_ENABLE=0)
-add_compile_definitions(IREE_USER_CONFIG_H="${SPRINGBOK_CONFIG_HEADER}")
+add_compile_definitions(IREE_USER_CONFIG_H="${SPARROW_CONFIG_HEADER}")
 if (NOT BUILD_NO_WMMU)
   add_compile_definitions(IREE_HAL_COMMAND_BUFFER_VALIDATION_ENABLE=0)
   add_compile_definitions(IREE_HAL_MODULE_STRING_UTIL_ENABLE=0)
@@ -91,13 +91,13 @@
 # Apply IREE's CMake variables and build options so we can use IREE build
 # functions properly in this project.
 set(IREE_ROOT_DIR "${IREE_SOURCE_DIR}" CACHE PATH "IREE Root directory")
-include(springbok_ops)
+include(sparrow_ops)
 
-include(springbok_static_module)
-include(springbok_vmvx_module)
-include(springbok_modules)
+include(sparrow_static_module)
+include(sparrow_vmvx_module)
+include(sparrow_modules)
 include(iree_model_input)
-include(springbok_test)
+include(sparrow_test)
 
 # softmax op (and mfcc) requires floorf implementation in libm. Use the nano
 # version.
diff --git a/audio_prep/CMakeLists.txt b/audio_prep/CMakeLists.txt
index 5678353..2261fbe 100644
--- a/audio_prep/CMakeLists.txt
+++ b/audio_prep/CMakeLists.txt
@@ -24,7 +24,7 @@
   target_compile_definitions(audio_prep_mfcc PUBLIC MFCC_WITH_RVV)
 endif()
 
-springbok_test(
+sparrow_test(
   NAME
     mfcc_test
   SRCS
diff --git a/cmake/springbok_ops.cmake b/cmake/sparrow_ops.cmake
similarity index 100%
rename from cmake/springbok_ops.cmake
rename to cmake/sparrow_ops.cmake
diff --git a/cmake/springbok_static_module.cmake b/cmake/sparrow_static_module.cmake
similarity index 97%
rename from cmake/springbok_static_module.cmake
rename to cmake/sparrow_static_module.cmake
index 7fef4cb..a42e3c6 100644
--- a/cmake/springbok_static_module.cmake
+++ b/cmake/sparrow_static_module.cmake
@@ -1,4 +1,4 @@
-# springbok_static_module()
+# sparrow_static_module()
 #
 # A modified version of iree_static_linker_test to apply common iree-compile flags
 # Parameters:
@@ -11,7 +11,7 @@
 # INLINE_HAL: Use inline HAL.
 #
 # Examples:
-# springbok_static_module(
+# sparrow_static_module(
 #   NAME
 #     daredevel_bytecode_module_static
 #   SRC
@@ -22,7 +22,7 @@
 #     "-iree-input-type=tosa"
 # )
 #
-# springbok_static_module(
+# sparrow_static_module(
 #   NAME
 #     simple_float_mul_c_module_static
 #   SRC
@@ -35,7 +35,7 @@
 #   EMITC
 # )
 #
-function(springbok_static_module)
+function(sparrow_static_module)
   cmake_parse_arguments(
     _RULE
     "RVV_OFF;EMITC;INLINE_HAL"
diff --git a/cmake/springbok_test.cmake b/cmake/sparrow_test.cmake
similarity index 96%
rename from cmake/springbok_test.cmake
rename to cmake/sparrow_test.cmake
index 5a42826..83a67a8 100644
--- a/cmake/springbok_test.cmake
+++ b/cmake/sparrow_test.cmake
@@ -1,6 +1,6 @@
 include(CMakeParseArguments)
 
-# springbok_test()
+# sparrow_test()
 #
 # A wrapper for the iree_cc_binary to attach lit run files to an executable
 # Parameters:
@@ -12,7 +12,7 @@
 # TESTFILES: List of lit test run files
 #
 # Examples:
-# springbok_test(
+# sparrow_test(
 #   NAME
 #     simple_int_vec_mul_emitc_static
 #   SRCS
@@ -26,7 +26,7 @@
 #   TESTFILES
 #     "simple_test.run"
 # )
-function(springbok_test)
+function(sparrow_test)
   cmake_parse_arguments(
     _RULE
     ""
diff --git a/cmake/springbok_vmvx_module.cmake b/cmake/sparrow_vmvx_module.cmake
similarity index 96%
rename from cmake/springbok_vmvx_module.cmake
rename to cmake/sparrow_vmvx_module.cmake
index 1af725a..60ee602 100644
--- a/cmake/springbok_vmvx_module.cmake
+++ b/cmake/sparrow_vmvx_module.cmake
@@ -1,4 +1,4 @@
-# springbok_vmvx_module()
+# sparrow_vmvx_module()
 #
 # A modified version of iree_vmvx_linker_test to apply common iree-compile flags
 # Parameters:
@@ -9,7 +9,7 @@
 # INLINE_HAL: Use inline HAL.
 #
 # Examples:
-# springbok_vmvx_module(
+# sparrow_vmvx_module(
 #   NAME
 #     daredevel_bytecode_module_vmvx
 #   SRC
@@ -20,7 +20,7 @@
 #     "-iree-input-type=tosa"
 # )
 #
-# springbok_vmvx_module(
+# sparrow_vmvx_module(
 #   NAME
 #     simple_float_mul_c_module_vmvx
 #   SRC
@@ -32,7 +32,7 @@
 #   EMITC
 # )
 #
-function(springbok_vmvx_module)
+function(sparrow_vmvx_module)
   cmake_parse_arguments(
     _RULE
     "EMITC;INLINE_HAL"
diff --git a/risp4ml/common/CMakeLists.txt b/risp4ml/common/CMakeLists.txt
index 65bb9b1..5900d8d 100644
--- a/risp4ml/common/CMakeLists.txt
+++ b/risp4ml/common/CMakeLists.txt
@@ -25,7 +25,7 @@
     "utils.c"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     image_test
   SRCS
diff --git a/risp4ml/isp_stages/CMakeLists.txt b/risp4ml/isp_stages/CMakeLists.txt
index 0c94055..7b039bb 100644
--- a/risp4ml/isp_stages/CMakeLists.txt
+++ b/risp4ml/isp_stages/CMakeLists.txt
@@ -96,7 +96,7 @@
     risp4ml::common::utils
 )
 
-springbok_test(
+sparrow_test(
   NAME
     blc_test
   SRCS
@@ -111,7 +111,7 @@
     "blc_test.run"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     dg_test
   SRCS
@@ -126,7 +126,7 @@
     "dg_test.run"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     downscale_test
   SRCS
@@ -140,7 +140,7 @@
     "downscale_test.run"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     gamma_test
   SRCS
@@ -154,7 +154,7 @@
     "gamma_test.run"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     wbg_test
   SRCS
diff --git a/samples/microbenchmarks/CMakeLists.txt b/samples/microbenchmarks/CMakeLists.txt
index ccc73db..e28f5b0 100644
--- a/samples/microbenchmarks/CMakeLists.txt
+++ b/samples/microbenchmarks/CMakeLists.txt
@@ -4,7 +4,7 @@
 # https://github.com/llvm/llvm-project/blob/0eeab8b/llvm/lib/Target/RISCV/RISCVSubtarget.cpp#L30-L51
 # -------------------------------------------------------------------------------
 
-springbok_static_module(
+sparrow_static_module(
   NAME
     conv1x1_test
   SRC
@@ -15,7 +15,7 @@
   EMITC
 )
 
-springbok_vmvx_module(
+sparrow_vmvx_module(
   NAME
     conv1x1_test_vmvx
   SRC
@@ -41,7 +41,7 @@
     "-DBUILD_VMVX"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     conv1x1_test_emitc_static
   SRCS
diff --git a/samples/simple_vec_mul/CMakeLists.txt b/samples/simple_vec_mul/CMakeLists.txt
index 74e9dc8..e6844ad 100644
--- a/samples/simple_vec_mul/CMakeLists.txt
+++ b/samples/simple_vec_mul/CMakeLists.txt
@@ -4,7 +4,7 @@
 # https://github.com/llvm/llvm-project/blob/0eeab8b/llvm/lib/Target/RISCV/RISCVSubtarget.cpp#L30-L51
 #-------------------------------------------------------------------------------
 
-springbok_modules(
+sparrow_modules(
   NAME
     simple_float_mul
   SRC
@@ -18,7 +18,7 @@
   INLINE_HAL
 )
 
-springbok_modules(
+sparrow_modules(
   NAME
     simple_int_mul
   SRC
@@ -150,7 +150,7 @@
     "LINKER:--defsym=__stack_size__=20k"
 )
 
-springbok_test(
+sparrow_test(
   NAME
     simple_int_vec_mul_emitc_static
   SRCS
diff --git a/springbok_config.h b/sparrow_config.h
similarity index 81%
rename from springbok_config.h
rename to sparrow_config.h
index eebe8f3..b699b35 100644
--- a/springbok_config.h
+++ b/sparrow_config.h
@@ -14,20 +14,18 @@
  * limitations under the License.
  */
 
-// Springbok-specific implementation for some IREE functions.
+// Sparrow-specific implementation for some IREE functions.
 
-#ifndef SPRINGBOK_CONFIG_H
-#define SPRINGBOK_CONFIG_H
+#ifndef SPARROW_CONFIG_H_
+#define SPARROW_CONFIG_H_
 
 // IREE_TIME_NOW_FN is required and used to fetch the current RTC time and to be
 // used for wait handling. A thread-less system can just return 0.
 #define IREE_TIME_NOW_FN \
-  {                      \
-    return 0;            \
-  }
+  { return 0; }
 
 // IREE_DEVICE_SIZE_T for status print out.
 #define IREE_DEVICE_SIZE_T uint32_t
 #define PRIdsz PRIu32
 
-#endif // SPRINGBOK_CONFIG_H
+#endif  // SPARROW_CONFIG_H_
diff --git a/cmake/springbok_modules.cmake b/cmake/sparrow_modules.cmake
similarity index 86%
rename from cmake/springbok_modules.cmake
rename to cmake/sparrow_modules.cmake
index ba3c6bc..ce95e87 100644
--- a/cmake/springbok_modules.cmake
+++ b/cmake/sparrow_modules.cmake
@@ -1,6 +1,6 @@
-# springbok_modules()
+# sparrow_modules()
 #
 # A wrapper for the springbok_bytecode_module and springbok_c_module to apply common iree-compile flags
 # Parameters:
 # NAME: Name of target.
 # SRC: Source file to compile into a bytecode module. Support relative path.
@@ -12,7 +12,7 @@
 # INLINE_HAL: Use inline HAL.
 #
 # Examples:
-# springbok_modules(
+# sparrow_modules(
 #   NAME
 #     dare_devel
 #   SRC
@@ -23,7 +23,7 @@
 #     "-iree-input-type=tosa"
 # )
 #
-# springbok_modules(
+# sparrow_modules(
 #   NAME
 #     simple_float_mul
 #   SRC
@@ -37,7 +37,7 @@
 # )
 #
 
-function(springbok_modules)
+function(sparrow_modules)
   cmake_parse_arguments(
     _RULE
     "PUBLIC;RVV_OFF;VMVX;INLINE_HAL"
@@ -54,7 +54,7 @@
     set(_INLINE_HAL_ARG "INLINE_HAL")
   endif()
 
-  springbok_static_module(
+  sparrow_static_module(
     NAME
       "${_RULE_NAME}_bytecode_module_static"
     SRC
@@ -67,7 +67,7 @@
     "${_INLINE_HAL_ARG}"
   )
 
-  springbok_static_module(
+  sparrow_static_module(
     NAME
       "${_RULE_NAME}_c_module_static"
     SRC
@@ -80,7 +80,7 @@
   )
 
   if (${_RULE_VMVX})
-    springbok_vmvx_module(
+    sparrow_vmvx_module(
       NAME
         "${_RULE_NAME}_bytecode_module_vmvx"
       SRC
@@ -92,7 +92,7 @@
       "${_INLINE_HAL_ARG}"
     )
 
-    springbok_vmvx_module(
+    sparrow_vmvx_module(
       NAME
         "${_RULE_NAME}_c_module_vmvx"
       SRC
@@ -1,6 +1,6 @@
 #
-# A wrapper for the springbok_bytecode_module and springbok_c_module to apply common iree-compile flags
+# A wrapper for the sparrow_static_module and sparrow_vmvx_module to apply common iree-compile flags
 # Parameters:
 # NAME: Name of target.